@@ -22,10 +22,10 @@ def test_saml2aws(
         with capture_command():
             saml2aws.exec("aws", "ssm", "start-session", target="i-0123456789abcdef")
     capture_command.assert_command(
-        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml login",
-        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- 'aws ssm start-session --target i-0123456789abcdef'",
+        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt exec -- env",
+        f"saml2aws --version",
+        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt login",
+        f"saml2aws --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt exec -- 'aws ssm start-session --target i-0123456789abcdef'",
     )
 
 
@@ -69,10 +69,10 @@ def test_saml2aws_debug(
         with capture_command():
             saml2aws.exec("env")
     capture_command.assert_command(
-        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml login",
-        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt --cache-saml exec -- env",
+        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt exec -- env",
+        f"saml2aws --version",
+        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt login",
+        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym-catamorphic --skip-prompt exec -- env",
     )
 
 
@@ -81,10 +81,10 @@ def test_saml2aws_multi_threads(subprocess_friendly_asserter) -> None:
     with sandbox.push_xdg_config_home():
         config_file = SymConfigFile(resource="test", file_name="saml2aws.cfg")
     commands = (
-        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt --cache-saml exec -- env",
-        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt --cache-saml login",
-        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt --cache-saml exec -- env",
+        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt exec -- env",
+        f"saml2aws --version",
+        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt login",
+        f"saml2aws --config {config_file} --idp-account sym-test --skip-prompt exec -- env",
     )
     with Pool(processes=4) as pool:
         pool.map(f, [(constructor, sandbox, commands)] * 100)
